@@ -2,7 +2,7 @@ package Foorum::Controller::Comment;
 
 use strict;
 use warnings;
-our $VERSION = '1.000005';
+our $VERSION = '1.000006';
 use base 'Catalyst::Controller';
 use Foorum::Utils qw/encodeHTML/;
 
@@ -234,15 +234,9 @@ sub reply : LocalRegex('^(\d+)/reply$') {
 
     # go this comment
     $comment_id = $new_comment->comment_id;
-    $path .= "/comment_id=$comment_id/#c$comment_id";
+    $path .= "/comment_id=$comment_id/?info=1#c$comment_id";
 
-    $c->forward(
-        '/print_message',
-        [   {   msg => 'Post Reply OK',
-                url => $path,
-            }
-        ]
-    );
+    $c->res->redirect($path);
 }
 
 sub edit : LocalRegex('^(\d+)/edit$') {
@@ -339,15 +333,9 @@ sub edit : LocalRegex('^(\d+)/edit$') {
     $c->cache->remove($cache_key);
 
     # go this comment
-    $path .= "/comment_id=$comment_id/#c$comment_id";
+    $path .= "/comment_id=$comment_id/?info=1#c$comment_id";
 
-    $c->forward(
-        '/print_message',
-        [   {   msg => 'Edit Reply OK',
-                url => $path,
-            }
-        ]
-    );
+    $c->res->redirect($path);
 }
 
 sub delete : LocalRegex('^(\d+)/delete$') {
@@ -462,13 +450,7 @@ sub delete : LocalRegex('^(\d+)/delete$') {
             { total_replies => \"total_replies - $delete_counts" } );
     }
 
-    $c->forward(
-        '/print_message',
-        [   {   msg => 'Delete Reply OK',
-                url => $path,
-            }
-        ]
-    );
+    $c->res->redirect("$path?info=1");
 }
 
 sub validate_params : Private {
